Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src fix various typos, mainly in comments.



details:   https://anonhg.NetBSD.org/src/rev/964220cb7904
branches:  trunk
changeset: 361593:964220cb7904
user:      andvar <andvar%NetBSD.org@localhost>
date:      Wed Feb 16 22:00:55 2022 +0000

description:
fix various typos, mainly in comments.

diffstat:

 sbin/nvmectl/identify.c                 |   6 +-
 sys/arch/aarch64/aarch64/pmap.c         |   6 +-
 sys/arch/arm/samsung/exynos4_reg.h      |   4 +-
 sys/dev/ata/satareg.h                   |   4 +-
 sys/dev/ic/mvsatareg.h                  |  10 +++---
 sys/dev/marvell/if_mvxpe.c              |   6 +-
 sys/dev/marvell/if_mvxpevar.h           |   6 +-
 sys/dev/pci/if_sip.c                    |   6 +-
 sys/dev/raidframe/rf_evenodd_dagfuncs.c |  54 ++++++++++++++++----------------
 sys/dev/usb/if_atureg.h                 |   4 +-
 sys/fs/nilfs/nilfs_fs.h                 |   4 +-
 sys/fs/udf/udf_vnops.c                  |   6 +-
 sys/net80211/ieee80211_node.h           |   4 +-
 sys/netinet/ip_reass.c                  |   6 +-
 sys/netinet/sctp_timer.c                |  12 +++---
 15 files changed, 69 insertions(+), 69 deletions(-)

diffs (truncated from 568 to 300 lines):

diff -r eb190004ba7e -r 964220cb7904 sbin/nvmectl/identify.c
--- a/sbin/nvmectl/identify.c   Wed Feb 16 20:31:43 2022 +0000
+++ b/sbin/nvmectl/identify.c   Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: identify.c,v 1.7 2020/09/27 16:45:21 jdolecek Exp $    */
+/*     $NetBSD: identify.c,v 1.8 2022/02/16 22:00:55 andvar Exp $      */
 
 /*-
  * SPDX-License-Identifier: BSD-2-Clause-FreeBSD
@@ -30,7 +30,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: identify.c,v 1.7 2020/09/27 16:45:21 jdolecek Exp $");
+__RCSID("$NetBSD: identify.c,v 1.8 2022/02/16 22:00:55 andvar Exp $");
 #if 0
 __FBSDID("$FreeBSD: head/sbin/nvmecontrol/identify.c 329824 2018-02-22 13:32:31Z wma $");
 #endif
@@ -88,7 +88,7 @@
        printf("Firmware Activate/Download:  %s\n",
                (cdata->oacs & NVME_ID_CTRLR_OACS_FW) ?
                "Supported" : "Not Supported");
-       printf("Namespace Managment:         %s\n",
+       printf("Namespace Management:         %s\n",
                (cdata->oacs & NVME_ID_CTRLR_OACS_NS) ?
                "Supported" : "Not Supported");
        printf("Abort Command Limit:         %d\n", cdata->acl+1);
diff -r eb190004ba7e -r 964220cb7904 sys/arch/aarch64/aarch64/pmap.c
--- a/sys/arch/aarch64/aarch64/pmap.c   Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/arch/aarch64/aarch64/pmap.c   Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap.c,v 1.127 2022/01/31 09:16:09 ryo Exp $   */
+/*     $NetBSD: pmap.c,v 1.128 2022/02/16 22:00:55 andvar Exp $        */
 
 /*
  * Copyright (c) 2017 Ryo Shimizu <ryo%nerv.org@localhost>
@@ -27,7 +27,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.127 2022/01/31 09:16:09 ryo Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.128 2022/02/16 22:00:55 andvar Exp $");
 
 #include "opt_arm_debug.h"
 #include "opt_cpuoptions.h"
@@ -1620,7 +1620,7 @@
 }
 
 /*
- * decrement reference counter of the page descriptr page.
+ * decrement reference counter of the page descriptor page.
  * if reference counter is 1(=empty), pages will be freed, and return true.
  * otherwise return false.
  * kernel page, or L0 page descriptor page will be never freed.
diff -r eb190004ba7e -r 964220cb7904 sys/arch/arm/samsung/exynos4_reg.h
--- a/sys/arch/arm/samsung/exynos4_reg.h        Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/arch/arm/samsung/exynos4_reg.h        Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: exynos4_reg.h,v 1.15 2018/08/19 07:27:33 skrll Exp $   */
+/*     $NetBSD: exynos4_reg.h,v 1.16 2022/02/16 22:00:55 andvar Exp $  */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -127,7 +127,7 @@
 #define EXYNOS4_RTC_OFFSET                     0x00070000      /* Real Time Clock */
 #define EXYNOS4_KEYIF_OFFSET                   0x000A0000      /* Keypad interface */
 #define EXYNOS4_HDMI_CEC_OFFSET                        0x000B0000      /* HDMI Consumer Electronic Control */
-#define EXYNOS4_TMU_OFFSET                     0x000C0000      /* Thermal Managment */
+#define EXYNOS4_TMU_OFFSET                     0x000C0000      /* Thermal Management */
 #define EXYNOS4_SECKEY_OFFSET                  0x00100000      /* XXX unknown XXX */
 #define EXYNOS4_TZPC0_OFFSET                   0x00110000      /* ARM Trusted Zone Protection Controller */
 #define EXYNOS4_TZPC1_OFFSET                   0x00120000
diff -r eb190004ba7e -r 964220cb7904 sys/dev/ata/satareg.h
--- a/sys/dev/ata/satareg.h     Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/ata/satareg.h     Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: satareg.h,v 1.6 2020/12/27 15:15:45 jmcneill Exp $     */
+/*     $NetBSD: satareg.h,v 1.7 2022/02/16 22:00:55 andvar Exp $       */
 
 /*-
  * Copyright (c) 2003 The NetBSD Foundation, Inc.
@@ -69,7 +69,7 @@
 #define        SStatus_SPD_mask        (0xf << 4)
 #define        SStatus_SPD_shift       4
        /*
-        * The IPM value indicates the current interface power managemnt
+        * The IPM value indicates the current interface power management
         * state.
         */
 #define        SStatus_IPM_NODEV       (0x0 << 8)      /* no device connected */
diff -r eb190004ba7e -r 964220cb7904 sys/dev/ic/mvsatareg.h
--- a/sys/dev/ic/mvsatareg.h    Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/ic/mvsatareg.h    Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mvsatareg.h,v 1.4 2017/10/07 16:05:32 jdolecek Exp $   */
+/*     $NetBSD: mvsatareg.h,v 1.5 2022/02/16 22:00:55 andvar Exp $     */
 /*
  * Copyright (c) 2008 KIYOHARA Takashi
  * All rights reserved.
@@ -250,15 +250,15 @@
 
 /* EDMA Command Request Block (CRQB) Data */
 struct crqb {
-       uint32_t cprdbl;        /* cPRD Desriptor Table Base Low Address */
-       uint32_t cprdbh;        /* cPRD Desriptor Table Base High Address */
+       uint32_t cprdbl;        /* cPRD Descriptor Table Base Low Address */
+       uint32_t cprdbh;        /* cPRD Descriptor Table Base High Address */
        uint16_t ctrlflg;       /* Control Flags */
        uint16_t atacommand[11];
 } __packed __aligned(8);
 
 struct crqb_gen2e {
-       uint32_t cprdbl;        /* cPRD Desriptor Table Base Low Address */
-       uint32_t cprdbh;        /* cPRD Desriptor Table Base High Address */
+       uint32_t cprdbl;        /* cPRD Descriptor Table Base Low Address */
+       uint32_t cprdbh;        /* cPRD Descriptor Table Base High Address */
        uint32_t ctrlflg;       /* Control Flags */
        uint32_t drbc;          /* Data Region Byte Count */
        uint8_t atacommand[16];
diff -r eb190004ba7e -r 964220cb7904 sys/dev/marvell/if_mvxpe.c
--- a/sys/dev/marvell/if_mvxpe.c        Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/marvell/if_mvxpe.c        Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_mvxpe.c,v 1.38 2022/02/12 03:24:35 riastradh Exp $  */
+/*     $NetBSD: if_mvxpe.c,v 1.39 2022/02/16 22:00:56 andvar Exp $     */
 /*
  * Copyright (c) 2015 Internet Initiative Japan Inc.
  * All rights reserved.
@@ -25,7 +25,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_mvxpe.c,v 1.38 2022/02/12 03:24:35 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_mvxpe.c,v 1.39 2022/02/16 22:00:56 andvar Exp $");
 
 #include "opt_multiprocessor.h"
 
@@ -2611,7 +2611,7 @@
                return ENOBUFS;
        }
 
-       /* Add the packet to descritor */
+       /* Add the packet to descriptor */
        KASSERT(MVXPE_RX_PKTBUF(sc, q, rx->rx_cpu) == NULL);
        MVXPE_RX_PKTBUF(sc, q, rx->rx_cpu) = chunk;
        mvxpbm_dmamap_sync(chunk, BM_SYNC_ALL, BUS_DMASYNC_PREREAD);
diff -r eb190004ba7e -r 964220cb7904 sys/dev/marvell/if_mvxpevar.h
--- a/sys/dev/marvell/if_mvxpevar.h     Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/marvell/if_mvxpevar.h     Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_mvxpevar.h,v 1.6 2021/12/05 02:47:01 msaitoh Exp $  */
+/*     $NetBSD: if_mvxpevar.h,v 1.7 2022/02/16 22:00:56 andvar Exp $   */
 /*
  * Copyright (c) 2015 Internet Initiative Japan Inc.
  * All rights reserved.
@@ -117,7 +117,7 @@
        struct mvxpe_rx_desc            *rx_descriptors;
        bus_dmamap_t                    rx_descriptors_map;
 
-       /* Managment entries for each of descritors */
+       /* Management entries for each of descriptors */
        struct mvxpe_rx_handle {
                struct mvxpe_rx_desc    *rxdesc_va;
                off_t                   rxdesc_off; /* from rx_descriptors[0] */
@@ -143,7 +143,7 @@
        struct mvxpe_tx_desc            *tx_descriptors;
        bus_dmamap_t                    tx_descriptors_map;
 
-       /* Managment entries for each of descritors */
+       /* Management entries for each of descriptors */
        struct mvxpe_tx_handle {
                struct mvxpe_tx_desc    *txdesc_va;
                off_t                   txdesc_off; /* from tx_descriptors[0] */
diff -r eb190004ba7e -r 964220cb7904 sys/dev/pci/if_sip.c
--- a/sys/dev/pci/if_sip.c      Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/pci/if_sip.c      Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_sip.c,v 1.184 2021/12/31 14:25:23 riastradh Exp $   */
+/*     $NetBSD: if_sip.c,v 1.185 2022/02/16 22:00:56 andvar Exp $      */
 
 /*-
  * Copyright (c) 2001, 2002 The NetBSD Foundation, Inc.
@@ -73,7 +73,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_sip.c,v 1.184 2021/12/31 14:25:23 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_sip.c,v 1.185 2022/02/16 22:00:56 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -1702,7 +1702,7 @@
                    BUS_DMASYNC_PREREAD | BUS_DMASYNC_PREWRITE);
 
                /*
-                * The entire packet is set up.  Give the first descrptor
+                * The entire packet is set up.  Give the first descriptor
                 * to the chip now.
                 */
                sc->sc_txdescs[sc->sc_txnext].sipd_words[sc->sc_cmdsts_idx] |=
diff -r eb190004ba7e -r 964220cb7904 sys/dev/raidframe/rf_evenodd_dagfuncs.c
--- a/sys/dev/raidframe/rf_evenodd_dagfuncs.c   Wed Feb 16 20:31:43 2022 +0000
+++ b/sys/dev/raidframe/rf_evenodd_dagfuncs.c   Wed Feb 16 22:00:55 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rf_evenodd_dagfuncs.c,v 1.24 2019/10/10 03:43:59 christos Exp $        */
+/*     $NetBSD: rf_evenodd_dagfuncs.c,v 1.25 2022/02/16 22:00:56 andvar Exp $  */
 /*
  * Copyright (c) 1995 Carnegie-Mellon University.
  * All rights reserved.
@@ -31,7 +31,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: rf_evenodd_dagfuncs.c,v 1.24 2019/10/10 03:43:59 christos Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rf_evenodd_dagfuncs.c,v 1.25 2022/02/16 22:00:56 andvar Exp $");
 
 #include "rf_archs.h"
 
@@ -79,7 +79,7 @@
  *  be used. The previous case is when write access at least sectors of full stripe unit.
  *  The later function is used when the write access two stripe units but with total sectors
  *  less than sectors per SU. In this case, the access of parity and 'E' are shown as disconnected
- *  areas in their stripe unit and  parity write and 'E' write are both devided into two distinct
+ *  areas in their stripe unit and  parity write and 'E' write are both divided into two distinct
  *  writes( totally four). This simple old-new write and regular old-new write happen as in RAID-5
  ************************************************************************************************/
 
@@ -168,8 +168,8 @@
                                                                                                                 * writeDataNodes */
                /* bxor to buffer of readDataNodes */
                retcode = rf_bxor(node->params[5].p, node->params[1].p, length);
                /* find out the corresponding colume in encoding matrix for
                 * write colume to be encoded into redundant disk 'E' */
                scol = rf_EUCol(layoutPtr, pda->raidAddress);
                srcbuf = node->params[1].p;
                destbuf = node->params[3].p;
@@ -233,10 +233,10 @@
  *     one stripe unit is not allowed so that the write can be dealt with like a
  *     large write.
  *  The following function is based on these assumptions. So except in the second case,
- *  it looks the same as a large write encodeing function. But this is not exactly the
+ *  it looks the same as a large write encoding function. But this is not exactly the
  *  normal way for doing a degraded write, since raidframe have to break cases of access
  *  other than the above two into smaller accesses. We may have to change
- *  DegrESubroutin in the future.
+ *  DegrESubroutine in the future.
  *******************************************************************************************/
 void
 rf_DegrESubroutine(RF_DagNode_t *node, char *ebuf)
@@ -297,10 +297,10 @@
                                 * be Xored into all EUs in a dest sector */
        int     numRowInEncMatix = (RF_EO_MATRIX_DIM) - 1;
        RF_RowCol_t j, indexInDest,     /* row index of an encoding unit in
                                         * the destination colume of encoding
                                         * matrix */
                indexInSrc;     /* row index of an encoding unit in the source
                                 * colume used for recovery */
        int     bytesPerEU = bytesPerSector / numRowInEncMatix;
 
 #if RF_EO_MATRIX_DIM > 17
@@ -406,7 +406,7 @@
                        if (node->params[i + 1].p != node->results[0]) {
                                pda = (RF_PhysDiskAddr_t *) node->params[i].p;
                                if (i == node->numParams - 4)
-                                       scol = RF_EO_MATRIX_DIM - 2;    /* the colume of
+                                       scol = RF_EO_MATRIX_DIM - 2;    /* the column of
                                                                         * redundant E */
                                else
                                        scol = rf_EUCol(layoutPtr, pda->raidAddress);
@@ -481,7 +481,7 @@
        RF_ASSERT(*((long *) dest[1]) == 0);
        RF_ASSERT(*P == 0);
        /* calculate the 'P' parameter, which, not parity, is the Xor of all
-        * elements in the last two column, ie. 'E' and 'parity' colume, see
+        * elements in the last two columns, ie. 'E' and 'parity' columns, see
         * the Ref. paper by Blaum, et al 1993  */
        for (i = 0; i < numRowInEncMatix; i++)
                for (k = 0; k < longsPerEU; k++) {
@@ -527,7 +527,7 @@
                dest_smaller_current = dest_smaller + row * longsPerEU;
 #endif
                /**    Do the diagonal recovery. Initially, temp[k] = (failed 1),
-                      which is the failed data in the colume which has smaller col index. **/
+                      which is the failed data in the column which has smaller col index. **/
                /* step 1:  ^(SUM of nonfailed in-diagonal A(rrdrow,0..m-3))         */
                for (j = 0; j < numDataCol; j++) {
                        if (j == f1 || j == f2)
@@ -545,7 +545,7 @@
 #endif
                        }
                }
-               /* step 2:  ^E(erow,m-2), If erow is at the buttom row, don't
+               /* step 2:  ^E(erow,m-2), If erow is at the bottom row, don't
                 * Xor into it  E(erow,m-2) = (principle diagonal) ^ (failed
                 * 1) ^ (failed 2) ^ ( SUM of nonfailed in-diagonal
                 * A(rrdrow,0..m-3) ) After this step, temp[k] = (principle
@@ -168,8 +168,8 @@
                /* bxor to buffer of readDataNodes */
                retcode = rf_bxor(node->params[5].p, node->params[1].p, length);
-               /* find out the corresponding colume in encoding matrix for
-                * write colume to be encoded into redundant disk 'E' */
+               /* find out the corresponding column in encoding matrix for
+                * write column to be encoded into redundant disk 'E' */
                scol = rf_EUCol(layoutPtr, pda->raidAddress);
                srcbuf = node->params[1].p;
@@ -297,10 +297,10 @@
        int     numRowInEncMatix = (RF_EO_MATRIX_DIM) - 1;
        RF_RowCol_t j, indexInDest,     /* row index of an encoding unit in
-                                        * the destination colume of encoding
+                                        * the destination column of encoding
                                         * matrix */
                indexInSrc;     /* row index of an encoding unit in the source
@@ -297,10 +297,10 @@
                                         * matrix */
                indexInSrc;     /* row index of an encoding unit in the source
-                                * colume used for recovery */
+                                * column used for recovery */
        int     bytesPerEU = bytesPerSector / numRowInEncMatix;
 



Home | Main Index | Thread Index | Old Index